BlockV10Parameters

Struct BlockV10Parameters 

pub struct BlockV10Parameters {
Show 20 fields pub c: f64, pub dt: u64, pub ud0: usize, pub sig_period: u64, pub sig_stock: usize, pub sig_window: u64, pub sig_validity: u64, pub sig_qty: usize, pub idty_window: u64, pub ms_window: u64, pub x_percent: f64, pub ms_validity: u64, pub step_max: usize, pub median_time_blocks: usize, pub avg_gen_time: u64, pub dt_diff_eval: usize, pub percent_rot: f64, pub ud_time0: u64, pub ud_reeval_time0: u64, pub dt_reeval: u64,
}
Currency parameters

Fields

c: f64

UD target growth rate (see Relative Theorie of Money)

dt: u64

Duration between the creation of two UD (in seconds)

ud0: usize

Amount of the initial UD

sig_period: u64

Minimum duration between the writing of 2 certifications from the same issuer (in seconds)

sig_stock: usize

Maximum number of active certifications at the same time (for the same issuer)

sig_window: u64

Maximum retention period of a pending certification

sig_validity: u64

Time to expiry of written certification

sig_qty: usize

Minimum number of certifications required to become a member

idty_window: u64

Maximum retention period of a pending identity

ms_window: u64

Maximum retention period of a pending membership

x_percent: f64

Percentage of referring members who must be within step_max steps of each member

ms_validity: u64

Time to expiry of written membership

step_max: usize

For a member to respect the distance rule, there must exist for more than x_percent % of the referring members a path of less than step_max steps from the referring member to the evaluated member.

median_time_blocks: usize

Number of blocks used for calculating median time.

avg_gen_time: u64

The average time for writing 1 block (wished time)

dt_diff_eval: usize

The number of blocks required to evaluate again PoWMin value

percent_rot: f64

The percent of previous issuers to reach for personalized difficulty

ud_time0: u64

Time of first UD.

ud_reeval_time0: u64

Time of first reevaluation of the UD.

dt_reeval: u64

Time period between two re-evaluation of the UD.